==> qtjambi-qml-debuginfo-macos-6.8.0.jar: sources/QtJambiQml/QtQml_ValueCallback_shell.cpp <==
#include "QtQml_ValueCallback_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_QtQml_ValueCallback(void *ptr,bool) { delete reinterpret_cast<QtQml_ValueCallback_shell*>(ptr); }


QtQml_ValueCallback_shell::QtQml_ValueCallback_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QtQml_ValueCallback_shell::QtQml_ValueCallback_shell()", this)
    QtQml_ValueCallback_shell::__shell()->constructed(typeid(QtQml::ValueCallback));
}

// emitting (writeShellDestructor)
QtQml_ValueCallback_shell::~QtQml_ValueCallback_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QtQml_ValueCallback_shell::~QtQml_ValueCallback_shell()", this)
    QtQml_ValueCallback_shell::__shell()->destructed(typeid(QtQml::ValueCallback));
}

// construct QtQml_ValueCallback_shell
void __qt_construct_QtQml_ValueCallback(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool, bool, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QtQml::ValueCallback")
    new (__qtjambi_ptr) QtQml_ValueCallback_shell();
}
// destruct QtQml_ValueCallback_shell
void __qt_destruct_QtQml_ValueCallback(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtQml::ValueCallback")
    reinterpret_cast<QtQml_ValueCallback_shell*>(ptr)->~QtQml_ValueCallback_shell();
}

void QtQml_ValueCallback_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QtQml_ValueCallback_shell*>(ptr)->QtQml_ValueCallback_shell::__shell()->tryDeleteShell(typeid(QtQml::ValueCallback));
}

QtJambiShell* QtQml_ValueCallback_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QtQml_ValueCallback_shell) ); }

QtQml_ValueCallback_shell::Functor::Functor(QtQml_ValueCallback_shell& functional) : FunctorBase(typeid(QtQml::ValueCallback), functional) {}

QtQml_ValueCallback_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QtQml_ValueCallback_shell::Functor::~Functor() {}

QJSValue  QtQml_ValueCallback_shell::Functor::operator()(QQmlEngine* arg__1, QJSEngine* arg__2)
{
    QJSValue __qt_return_value = QJSValue();
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironmentExceptionHandler env{400}) {
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jobject __java_arg__1 = qtjambi_cast<jobject>(env, arg__1);
                    jobject __java_arg__2 = qtjambi_cast<jobject>(env, arg__2);
                    jobject __java_return_value = env->CallObjectMethod(__java_this, method_id, __java_arg__1, __java_arg__2);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                    QJSValue __qt_return_value_tmp = qtjambi_cast<QJSValue>(env, __java_return_value);
                    __qt_return_value = __qt_return_value_tmp;
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                env.handleException(exn, "QtQml::ValueCallback");
            } QTJAMBI_TRY_END
        }
    }
    return __qt_return_value;
}

void QtQml_ValueCallback_shell::getFunctional(JNIEnv *, void* result)
{
    *reinterpret_cast<QtQml::ValueCallback*>(result) = Functor(*this);
}

bool QtQml_ValueCallback_shell::isFunctionPointer()
{
    return false;
}

jobject QtQml_ValueCallback_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr){
        const QtQml::ValueCallback& function = *reinterpret_cast<const QtQml::ValueCallback*>(functionPtr);
        if(const QtQml_ValueCallback_shell::Functor* functor = function.target<QtQml_ValueCallback_shell::Functor>()){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QtQml_00024ValueCallback_00024Impl_00024ConcreteWrapper_apply_1native__JJ)
(JNIEnv *__jni_env, jobject __this, QtJambiNativeID arg__1, QtJambiNativeID arg__2)
{
    QTJAMBI_NATIVE_METHOD_CALL("ValueCallback(...)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QtQml::ValueCallback* function = QtJambiAPI::convertJavaInterfaceToNative<QtQml::ValueCallback>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        QQmlEngine* __qt_arg__1 = QtJambiAPI::objectFromNativeId<QQmlEngine>(arg__1);
        QJSEngine* __qt_arg__2 = QtJambiAPI::objectFromNativeId<QJSEngine>(arg__2);
        QJSValue  __qt_return_value = (*function)(__qt_arg__1, __qt_arg__2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QtQml_00024ValueCallback_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtQml_ValueCallback_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtQml_ValueCallback, sizeof(QtQml_ValueCallback_shell), typeid(QtQml::ValueCallback), 0, &deleter_QtQml_ValueCallback);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

void initialize_meta_info_QtQml_ValueCallback(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QtQml::ValueCallback, QtQml_ValueCallback_shell>("QtQml::ValueCallback", "io/qt/qml/QtQml$ValueCallback",
                              false,
                              &deleter_QtQml_ValueCallback,
                              &__qt_destruct_QtQml_ValueCallback,
                              {ConstructorInfo(&__qt_construct_QtQml_ValueCallback, nullptr)},
                              {FunctionInfo("apply", "(Lio/qt/qml/QQmlEngine;Lio/qt/qml/QJSEngine;)Lio/qt/qml/QJSValue;", FunctionInfo::Abstract)});
}

==> qtjambi-qml-debuginfo-macos-6.8.5.jar: sources/QtJambiQml/QtQml_ValueCallback_shell.cpp <==
#include "QtQml_ValueCallback_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_QtQml_ValueCallback(void *ptr,bool) { delete reinterpret_cast<QtQml_ValueCallback_shell*>(ptr); }


QtQml_ValueCallback_shell::QtQml_ValueCallback_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QtQml_ValueCallback_shell::QtQml_ValueCallback_shell()", this)
    QtQml_ValueCallback_shell::__shell()->constructed(typeid(QtQml::ValueCallback));
}

// emitting (writeShellDestructor)
QtQml_ValueCallback_shell::~QtQml_ValueCallback_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QtQml_ValueCallback_shell::~QtQml_ValueCallback_shell()", this)
    QtQml_ValueCallback_shell::__shell()->destructed(typeid(QtQml::ValueCallback));
}

// construct QtQml_ValueCallback_shell
void __qt_construct_QtQml_ValueCallback(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool, bool, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QtQml::ValueCallback")
    new (__qtjambi_ptr) QtQml_ValueCallback_shell();
}
// destruct QtQml_ValueCallback_shell
void __qt_destruct_QtQml_ValueCallback(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtQml::ValueCallback")
    reinterpret_cast<QtQml_ValueCallback_shell*>(ptr)->~QtQml_ValueCallback_shell();
}

void QtQml_ValueCallback_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QtQml_ValueCallback_shell*>(ptr)->QtQml_ValueCallback_shell::__shell()->tryDeleteShell(typeid(QtQml::ValueCallback));
}

QtJambiShell* QtQml_ValueCallback_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QtQml_ValueCallback_shell) ); }

QtQml_ValueCallback_shell::Functor::Functor(QtQml_ValueCallback_shell& functional) : FunctorBase(typeid(QtQml::ValueCallback), functional) {}

QtQml_ValueCallback_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QtQml_ValueCallback_shell::Functor::~Functor() {}

QJSValue  QtQml_ValueCallback_shell::Functor::operator()(QQmlEngine* arg__1, QJSEngine* arg__2)
{
    QJSValue __qt_return_value = QJSValue();
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironmentExceptionHandler env{400}) {
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jobject __java_arg__1 = qtjambi_cast<jobject>(env, arg__1);
                    jobject __java_arg__2 = qtjambi_cast<jobject>(env, arg__2);
                    jobject __java_return_value = env->CallObjectMethod(__java_this, method_id, __java_arg__1, __java_arg__2);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                    QJSValue __qt_return_value_tmp = qtjambi_cast<QJSValue>(env, __java_return_value);
                    __qt_return_value = __qt_return_value_tmp;
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                env.handleException(exn, this, "QtQml::ValueCallback");
            } QTJAMBI_TRY_END
        }
    }
    return __qt_return_value;
}

void QtQml_ValueCallback_shell::getFunctional(JNIEnv *, void* result)
{
    *reinterpret_cast<QtQml::ValueCallback*>(result) = Functor(*this);
}

bool QtQml_ValueCallback_shell::isFunctionPointer()
{
    return false;
}

jobject QtQml_ValueCallback_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr){
        const QtQml::ValueCallback& function = *reinterpret_cast<const QtQml::ValueCallback*>(functionPtr);
        if(const QtQml_ValueCallback_shell::Functor* functor = function.target<QtQml_ValueCallback_shell::Functor>()){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" JNIEXPORT jobject JNICALL Java_io_qt_qml_QtQml_00024ValueCallback_00024Impl_00024ConcreteWrapper_apply_1native__JJ
(JNIEnv *__jni_env, jobject __this, QtJambiNativeID arg__1, QtJambiNativeID arg__2)
{
    QTJAMBI_NATIVE_METHOD_CALL("ValueCallback(...)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QtQml::ValueCallback* function = QtJambiAPI::convertJavaInterfaceToNative<QtQml::ValueCallback>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        QQmlEngine* __qt_arg__1 = QtJambiAPI::objectFromNativeId<QQmlEngine>(arg__1);
        QJSEngine* __qt_arg__2 = QtJambiAPI::objectFromNativeId<QJSEngine>(arg__2);
        QJSValue  __qt_return_value = (*function)(__qt_arg__1, __qt_arg__2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QtQml_00024ValueCallback_00024Impl_initialize_1native
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtQml_ValueCallback_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtQml_ValueCallback, sizeof(QtQml_ValueCallback_shell), typeid(QtQml::ValueCallback), 0, &deleter_QtQml_ValueCallback);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

void initialize_meta_info_QtQml_ValueCallback(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QtQml::ValueCallback, QtQml_ValueCallback_shell>("QtQml::ValueCallback", "io/qt/qml/QtQml$ValueCallback",
                              false,
                              &deleter_QtQml_ValueCallback,
                              &__qt_destruct_QtQml_ValueCallback,
                              {ConstructorInfo{&__qt_construct_QtQml_ValueCallback, nullptr}},
                              {FunctionInfo{"apply", "(Lio/qt/qml/QQmlEngine;Lio/qt/qml/QJSEngine;)Lio/qt/qml/QJSValue;", FunctionInfo::Abstract}});
}
